@@ -162,10 +162,10 @@ class Py3status:
         self.last_known_status = ''
         # Guess mode if not set
         if self.measurement_mode is None:
-            if self.py3.check_commands(["acpi"]):
-                self.measurement_mode = "acpi"
-            elif os.path.isdir(self.sys_battery_path):
+            if os.path.isdir(self.sys_battery_path):
                 self.measurement_mode = "sys"
+            elif self.py3.check_commands(["acpi"]):
+                self.measurement_mode = "acpi"
 
         self.py3.log("Measurement mode: " + self.measurement_mode)
         if self.measurement_mode != "acpi" and self.measurement_mode != "sys":
@@ -279,7 +279,9 @@ class Py3status:
             r = _parse_battery_info(path)
 
             capacity = r.get("POWER_SUPPLY_ENERGY_FULL", r.get("POWER_SUPPLY_CHARGE_FULL"))
-            present_rate = r.get("POWER_SUPPLY_POWER_NOW", r.get("POWER_SUPPLY_CURRENT_NOW"))
+            present_rate = r.get("POWER_SUPPLY_POWER_NOW",
+                                 r.get("POWER_SUPPLY_CURRENT_NOW",
+                                       r.get("POWER_SUPPLY_VOLTAGE_NOW")))
             remaining_energy = r.get("POWER_SUPPLY_ENERGY_NOW", r.get("POWER_SUPPLY_CHARGE_NOW"))
 
             battery = {}
