@@ -36,9 +36,7 @@ Configuration parameters:
         Setting to `0` will disable cycling. (default 0)
     fixed_width: Reduce the size changes when switching to new group
         (default False)
-    format: Format for module output.
-        *(default "{output}" if click_mode is 'all',
-        "{output} {button}" if click_mode 'button')*
+    format: display format for this module, see Examples below (default None)
     format_button_closed: Format for the button when group open
         (default  '+')
     format_button_open: Format for the button when group closed
@@ -52,9 +50,14 @@ Format placeholders:
     {button} The button to open/close or change the displayed group
     {output} Output of current active module
 
-Example:
-
+Examples:
 ```
+# default formats
+group {
+    format = '{output}'           # if click_mode is 'all'
+    format = '{output} {button}'  # if click_mode is 'button'
+}
+
 # Create a disks group that will show space on '/' and '/home'
 # Change between disk modules every 30 seconds
 ...
@@ -90,7 +93,8 @@ cycle_again
 
 from time import time
 
-RETRY_TIMEOUT_NO_CONTENT = 5
+# maximum wait for initial content at startup
+MAX_NO_CONTENT_WAIT = 5
 
 
 class Py3status:
@@ -118,6 +122,7 @@ class Py3status:
         if not self.items:
             self.cycle = 0
 
+        self._first_run = True
         self.active = 0
         self.last_active = 0
         self.urgent = False
@@ -220,11 +225,17 @@ class Py3status:
             current_output = self._get_output()
             # if the output is empty try and find some output
             if not current_output:
+                if self._first_run:
+                    self._first_run = False
+                    return {
+                        'cached_until': self.py3.time_in(MAX_NO_CONTENT_WAIT),
+                        'full_text': '',
+                    }
+
                 self._change_active(1)
                 current_output = self._get_output()
                 # there is no output for any module retry later
-                if not current_output:
-                    update_time = RETRY_TIMEOUT_NO_CONTENT
+                self._first_run = False
         else:
             urgent = self.urgent
             current_output = []
