@@ -30,7 +30,6 @@ SAMPLE OUTPUT
 
 import re
 TEMP_RE = re.compile(r"Current Temp\s+:\s+([0-9]+)")
-STRING_ERROR = "nvidia_temp: unknown error"
 STRING_NOT_INSTALLED = 'not installed'
 STRING_UNAVAILABLE = "nvidia_temp: N/A"
 
@@ -65,15 +64,7 @@ class Py3status:
             raise Exception(STRING_NOT_INSTALLED)
 
     def nvidia_temp(self):
-        try:
-            temps = self.py3.command_output('nvidia-smi -q -d TEMPERATURE')
-        except:
-            return {
-                'cached_until': self.py3.time_in(self.cache_timeout),
-                'color': self.py3.COLOR_BAD,
-                'full_text': STRING_ERROR
-            }
-
+        temps = self.py3.command_output('nvidia-smi -q -d TEMPERATURE')
         temps = set(TEMP_RE.findall(temps))
         if temps == []:
             return {
