@@ -5,8 +5,8 @@ Display system RAM, SWAP and CPU utilization.
 Configuration parameters:
     cache_timeout: how often we refresh this module in seconds (default 10)
     format: output format string
-        *(default '[\?color=cpu CPU: {cpu_usage}%], '
-        '[\?color=mem Mem: {mem_used}/{mem_total} GB ({mem_used_percent}%)]')*
+        *(default '[\?color=cpu CPU: {cpu_used_percent}%], '
+        '[\?color=mem Mem: {mem_used}/{mem_total} {mem_unit} ({mem_used_percent}%)]')*
     mem_unit: the unit of memory to use in report, case insensitive.
         ['dynamic', 'KiB', 'MiB', 'GiB'] (default 'GiB')
     swap_unit: the unit of swap to use in report, case insensitive.
@@ -20,7 +20,7 @@ Configuration parameters:
 
 Format placeholders:
     {cpu_temp} cpu temperature
-    {cpu_usage} cpu usage percentage
+    {cpu_used_percent} cpu used percentage
     {load1} load average over the last minute
     {load5} load average over the five minutes
     {load15} load average over the fifteen minutes
@@ -35,8 +35,9 @@ Format placeholders:
     {temp_unit} temperature unit
 
 Color thresholds:
-    cpu: change color based on the value of cpu_usage
-    max_cpu_mem: change the color based on the max value of cpu_usage and mem_used_percent
+    cpu: change color based on the value of cpu_used_percent
+    max_cpu_mem: change the color based on the max value
+        of cpu_used_percent and mem_used_percent
     load: change color based on the value of load1
     mem: change color based on the value of mem_used_percent
     swap: change color based on the value of swap_used_percent
@@ -51,167 +52,23 @@ SAMPLE OUTPUT
 [
     {'color': '#00FF00', 'full_text': 'CPU: 9.60%'},
     {'full_text': ', '},
-    {'color': '#FFFF00', 'full_text': 'Mem: 1.91/3.76 GB (50.96%)'}
+    {'color': '#FFFF00', 'full_text': 'Mem: 1.91/3.76 GiB (50.96%)'}
 ]
 """
 
 from __future__ import division
+from os import getloadavg
 
 import re
 
-ONE_KIB = pow(1024, 1)  # 1 KiB in B
-ONE_MIB = pow(1024, 2)  # 1 MiB in B
-ONE_GIB = pow(1024, 3)  # 1 GiB in B
-
-
-class GetData:
-    """
-    Get system status
-    """
-
-    def __init__(self, parent):
-        self.py3 = parent.py3
-
-    def cpu(self):
-        """
-        Get the cpu usage data from /proc/stat :
-          cpu  2255 34 2290 22625563 6290 127 456 0 0
-          - user: normal processes executing in user mode
-          - nice: niced processes executing in user mode
-          - system: processes executing in kernel mode
-          - idle: twiddling thumbs
-          - iowait: waiting for I/O to complete
-          - irq: servicing interrupts
-          - softirq: servicing softirqs
-          - steal: involuntary wait
-          - guest: running a normal guest
-          - guest_nice: running a niced guest
-        These numbers identify the amount of time the CPU has spent performing
-        different kinds of work.  Time units are in USER_HZ
-        (typically hundredths of a second)
-        """
-        with open('/proc/stat', 'r') as fd:
-            line = fd.readline()
-        cpu_data = line.split()
-        total_cpu_time = sum(map(int, cpu_data[1:]))
-        cpu_idle_time = int(cpu_data[4])
-
-        # return the cpu total&idle time
-        return total_cpu_time, cpu_idle_time
-
-    def load(self):
-        """
-        Get the load average from /proc/loadavg :
-        """
-        with open('/proc/loadavg', 'r') as fd:
-            line = fd.readline()
-        load_data = line.split()
-        load1 = float(load_data[0])
-        load5 = float(load_data[1])
-        load15 = float(load_data[2])
-        return load1, load5, load15
-
-    def calc_mem_info(self, unit='GiB', memi=dict, keys=list):
-        """
-        Parse /proc/meminfo, grab the memory capacity and used size
-        then return; Memory size 'total_mem', Used_mem, percentage
-        of used memory, and units of mem (KiB, MiB, GiB).
-        """
-
-        total_mem_kib = memi[keys[0]]
-        mem_free = sum([memi[item] for item in keys[1:]])
-
-        try:
-            used_mem_kib = (total_mem_kib - mem_free)
-            used_mem_p = 100 * used_mem_kib / total_mem_kib
-            multiplier = {
-                'KiB': ONE_KIB / ONE_KIB,
-                'MiB': ONE_KIB / ONE_MIB,
-                'GiB': ONE_KIB / ONE_GIB,
-            }
-            if unit.lower() == 'dynamic':
-                # If less than 1 GiB, use MiB
-                if (multiplier['GiB'] * total_mem_kib) < 1:
-                    unit = 'MiB'
-                else:
-                    unit = 'GiB'
-            if unit in multiplier.keys():
-                total_mem = multiplier[unit] * total_mem_kib
-                used_mem = multiplier[unit] * used_mem_kib
-            else:
-                raise ValueError(
-                    'unit [{0}] must be one of: KiB, MiB, GiB, dynamic.'.format(unit))
-        except:
-            total_mem, used_mem, used_mem_p = [float('nan') for i in range(3)]
-            unit = 'UNKNOWN'
-
-        # If total memory is <1GB, results are in megabytes.
-        # Otherwise, results are in gigabytes.
-        return total_mem, used_mem, used_mem_p, unit
-
-    def mem(self, mem_unit='GiB', swap_unit='GiB', mem=True, swap=True):
-        memi = {}
-        result = {}
-
-        with open('/proc/meminfo', 'r') as fd:
-            for s in fd:
-                tok = s.split()
-                memi[tok[0]] = float(tok[1])
-
-        if mem:
-            result["mem"] = self.calc_mem_info(
-                mem_unit,
-                memi,
-                ["MemTotal:", "MemFree:", "Buffers:", "Cached:"]
-            )
-        if swap:
-            result["swap"] = self.calc_mem_info(
-                swap_unit,
-                memi,
-                ["SwapTotal:", "SwapFree:"]
-            )
-
-        return result
-
-    def cpuTemp(self, zone, unit):
-        """
-        Tries to determine CPU temperature using the 'sensors' command.
-        Searches for the CPU temperature by looking for a value prefixed
-        by either "CPU Temp" or "Core 0" - does not look for or average
-        out temperatures of all codes if more than one.
-        """
-
-        sensors = None
-        command = ['sensors']
-        if unit == u'°F':
-            command.append('-f')
-        elif unit not in [u'°C', 'K']:
-            return 'unknown unit'
-        if zone:
-            try:
-                sensors = self.py3.command_output(command + [zone])
-            except:
-                pass
-        if not sensors:
-            sensors = self.py3.command_output(command)
-        m = re.search("(Core 0|CPU Temp).+\+(.+).+\(.+", sensors)
-        if m:
-            cpu_temp = float(m.groups()[1].strip()[:-2])
-            if unit == 'K':
-                cpu_temp += 273.15
-        else:
-            cpu_temp = '?'
-
-        return cpu_temp
-
 
 class Py3status:
     """
     """
     # available configuration parameters
     cache_timeout = 10
-    format = "[\?color=cpu CPU: {cpu_usage}%], " \
-             "[\?color=mem Mem: {mem_used}/{mem_total} GB ({mem_used_percent}%)]"
+    format = "[\?color=cpu CPU: {cpu_used_percent}%], " \
+             "[\?color=mem Mem: {mem_used}/{mem_total} {mem_unit} ({mem_used_percent}%)]"
     mem_unit = 'GiB'
     swap_unit = 'GiB'
     temp_unit = u'°C'
@@ -237,6 +94,7 @@ class Py3status:
                                                            precision=precision)
             return {
                 'cpu_usage': format_vals,
+                'cpu_used_percent': format_vals,
                 'cpu_temp': format_vals,
                 'load1': format_vals,
                 'load5': format_vals,
@@ -253,6 +111,13 @@ class Py3status:
             'function': [
                 {'function': deprecate_function},
             ],
+            'rename_placeholder': [
+                {
+                    'placeholder': 'cpu_usage',
+                    'new': 'cpu_used_percent',
+                    'format_strings': ['format'],
+                },
+            ],
             'remove': [
                 {
                     'param': 'high_threshold',
@@ -284,6 +149,7 @@ class Py3status:
                 {
                     'placeholder_formats': {
                         'cpu_usage': ':.2f',
+                        'cpu_used_percent': ':.2f',
                         'cpu_temp': ':.2f',
                         'load1': ':.2f',
                         'load5': ':.2f',
@@ -301,9 +167,7 @@ class Py3status:
         }
 
     def post_config_hook(self):
-        self.data = GetData(self)
-        self.cpu_total = 0
-        self.cpu_idle = 0
+        self.last_cpu = {}
         temp_unit = self.temp_unit.upper()
         if temp_unit in ['C', u'°C']:
             temp_unit = u'°C'
@@ -311,74 +175,150 @@ class Py3status:
             temp_unit = u'°F'
         elif not temp_unit == 'K':
             temp_unit = 'unknown unit'
-        self.values = {'temp_unit': temp_unit}
         self.temp_unit = temp_unit
-        self.mem_info = self.py3.format_contains(self.format, 'mem_*')
-        self.swap_info = self.py3.format_contains(self.format, 'swap_*')
+        self.init = {'meminfo': []}
+        names = ['cpu_temp', 'cpu_percent', 'load', 'mem', 'swap']
+        placeholders = [
+            'cpu_temp', 'cpu_used_percent', 'load*', 'mem_*', 'swap_*'
+        ]
+        for name, placeholder in zip(names, placeholders):
+            self.init[name] = self.py3.format_contains(self.format, placeholder)
+            if name in ['mem', 'swap'] and self.init[name]:
+                self.init['meminfo'].append(name)
 
-    def sysData(self):
-        # get CPU usage info
-        if self.py3.format_contains(self.format, 'cpu_usage'):
-            cpu_total, cpu_idle = self.data.cpu()
-            cpu_usage = 0
-            if cpu_total != self.cpu_total:
-                cpu_usage = (1 - (
-                    float(cpu_idle - self.cpu_idle) / float(cpu_total - self.cpu_total)
-                )) * 100
-            self.values['cpu_usage'] = cpu_usage
-            self.cpu_total = cpu_total
-            self.cpu_idle = cpu_idle
-            self.py3.threshold_get_color(cpu_usage, 'cpu')
+    def _get_stat(self):
+        # kernel/system statistics. man -P 'less +//proc/stat' procfs
+        with open('/proc/stat') as f:
+            fields = f.readline().split()
+            return {
+                'total': sum(map(int, fields[1:])),
+                'idle': int(fields[4]),
+            }
 
-        # if specified as a formatting option, also get the CPU temperature
-        if self.py3.format_contains(self.format, 'cpu_temp'):
-            cpu_temp = self.data.cpuTemp(self.zone, self.temp_unit)
-            self.values['cpu_temp'] = cpu_temp
-            self.py3.threshold_get_color(cpu_temp, 'temp')
+    def _calc_mem_info(self, unit, meminfo, memory):
+        """
+        Parse /proc/meminfo, grab the memory capacity and used size
+        then return; Memory size 'total_mem', Used_mem, percentage
+        of used memory, and units of mem (KiB, MiB, GiB).
+        """
+        if memory:
+            total_mem_kib = meminfo['MemTotal:']
+            used_mem_kib = total_mem_kib - meminfo['MemFree:'] - (
+                meminfo['Buffers:'] + meminfo['Cached:'] + (
+                    meminfo['SReclaimable:'] - meminfo['Shmem:']
+                )
+            )
+        else:
+            total_mem_kib = meminfo['SwapTotal:']
+            used_mem_kib = total_mem_kib - meminfo['SwapFree:']
 
-        # get RAM/SWAP usage info
-        memi = self.data.mem(self.mem_unit, self.swap_unit, self.mem_info, self.swap_info)
+        used_mem_p = 100 * used_mem_kib / total_mem_kib
 
-        # set RAM usage info
-        if self.mem_info:
-            mem_total, mem_used, mem_used_percent, mem_unit = memi["mem"]
-            self.values['mem_total'] = mem_total
-            self.values['mem_used'] = mem_used
-            self.values['mem_used_percent'] = mem_used_percent
-            self.values['mem_unit'] = mem_unit
-            self.py3.threshold_get_color(mem_used_percent, 'mem')
+        unit = 'B' if unit == 'dynamic' else unit
+        (total_mem, unit) = self.py3.format_units(total_mem_kib * 1024, unit=unit)
+        (used_mem, _) = self.py3.format_units(used_mem_kib * 1024, unit=unit)
+        return total_mem, used_mem, used_mem_p, unit
 
-        # set SWAP usage info
-        if self.swap_info:
-            swap_total, swap_used, swap_used_percent, swap_unit = memi["swap"]
-            self.values['swap_total'] = swap_total
-            self.values['swap_used'] = swap_used
-            self.values['swap_used_percent'] = swap_used_percent
-            self.values['swap_unit'] = swap_unit
-            self.py3.threshold_get_color(swap_used_percent, 'swap')
+    def _get_mem(self, mem_unit, swap_unit, mem, swap):
+        meminfo = {}
+        result = {}
 
-        # get load average
-        if self.py3.format_contains(self.format, 'load*'):
-            load1, load5, load15 = self.data.load()
-            self.values['load1'] = load1
-            self.values['load5'] = load5
-            self.values['load15'] = load15
-            self.py3.threshold_get_color(load1, 'load')
+        with open('/proc/meminfo') as f:
+            for line in f:
+                fields = line.split()
+                meminfo[fields[0]] = float(fields[1])
 
-        try:
-            self.py3.threshold_get_color(max(cpu_usage, mem_used_percent), 'max_cpu_mem')
-        except:
+        if mem:
+            result["mem"] = self._calc_mem_info(mem_unit, meminfo, True)
+        if swap:
+            result["swap"] = self._calc_mem_info(swap_unit, meminfo, False)
+
+        return result
+
+    def _calc_cpu_percent(self, cpu):
+        cpu_used_percent = 0
+        if cpu['total'] != self.last_cpu.get('total'):
+            cpu_used_percent = (1 - (
+                (cpu['idle'] - self.last_cpu.get('idle', 0)) /
+                (cpu['total'] - self.last_cpu.get('total', 0))
+            )) * 100
+
+        self.last_cpu.update(cpu)
+        return cpu_used_percent
+
+    def _get_cputemp(self, zone, unit):
+        """
+        Tries to determine CPU temperature using the 'sensors' command.
+        Searches for the CPU temperature by looking for a value prefixed
+        by either "CPU Temp" or "Core 0" - does not look for or average
+        out temperatures of all codes if more than one.
+        """
+
+        sensors = None
+        command = ['sensors']
+        if unit == u'°F':
+            command.append('-f')
+        elif unit not in [u'°C', 'K']:
+            return 'unknown unit'
+        if zone:
             try:
-                self.py3.threshold_get_color(cpu_usage, 'max_cpu_mem')
-            except:
-                try:
-                    self.py3.threshold_get_color(mem_used_percent, 'max_cpu_mem')
-                except:
-                    pass
+                sensors = self.py3.command_output(command + [zone])
+            except self.py3.CommandError:
+                pass
+        if not sensors:
+            sensors = self.py3.command_output(command)
+        m = re.search("(Core 0|CPU Temp).+\+(.+).+\(.+", sensors)
+        if m:
+            cpu_temp = float(m.groups()[1].strip()[:-2])
+            if unit == 'K':
+                cpu_temp += 273.15
+        else:
+            cpu_temp = '?'
+
+        return cpu_temp
+
+    def sysdata(self):
+        sys = {'max_used_percent': 0, 'temp_unit': self.temp_unit}
+
+        if self.init['cpu_percent']:
+            sys['cpu_used_percent'] = self._calc_cpu_percent(self._get_stat())
+            self.py3.threshold_get_color(sys['cpu_used_percent'], 'cpu')
+
+        if self.init['cpu_temp']:
+            sys['cpu_temp'] = self._get_cputemp(self.zone, self.temp_unit)
+            self.py3.threshold_get_color(sys['cpu_temp'], 'temp')
+
+        if self.init['meminfo']:
+            memi = self._get_mem(
+                self.mem_unit, self.swap_unit,
+                self.init['mem'], self.init['swap']
+            )
+
+            if self.init['mem']:
+                mem_keys = [
+                    'mem_total', 'mem_used', 'mem_used_percent', 'mem_unit']
+                sys.update(zip(mem_keys, memi['mem']))
+                self.py3.threshold_get_color(sys['mem_used_percent'], 'mem')
+
+            if self.init['swap']:
+                swap_keys = [
+                    'swap_total', 'swap_used', 'swap_used_percent', 'swap_unit']
+                sys.update(zip(swap_keys, memi['swap']))
+                self.py3.threshold_get_color(sys['swap_used_percent'], 'swap')
+
+        if self.init['load']:
+            load_keys = ['load1', 'load5', 'load15']
+            sys.update(zip(load_keys, getloadavg()))
+            self.py3.threshold_get_color(sys['load1'], 'load')
+
+        sys['max_used_percent'] = max(
+            [perc for name, perc in sys.items() if 'used_percent' in name]
+        )
+        self.py3.threshold_get_color(sys['max_used_percent'], 'max_cpu_mem')
 
         response = {
             'cached_until': self.py3.time_in(self.cache_timeout),
-            'full_text': self.py3.safe_format(self.format, self.values)
+            'full_text': self.py3.safe_format(self.format, sys)
         }
 
         return response
@@ -389,5 +329,4 @@ if __name__ == "__main__":
     Run module in test mode.
     """
     from py3status.module_test import module_test
-
     module_test(Py3status)
